@@ -58,15 +58,14 @@ Update the job dependencies if using job_array (not batches)
 sub update_job_deps {
     my $self = shift;
 
-    return if $self->use_batches;
-
+    # return if $self->use_batches;
     return unless $self->has_array_deps;
 
     while(my($current_task, $v) = each %{$self->array_deps}){
       my $dep_tasks = join(':', @$v);
         my $cmd =
           "scontrol update job=$current_task Dependency=afterok:$dep_tasks";
-    #     # $self->app_log->warn($cmd);
+        # $self->app_log->warn($cmd);
     }
 }
 
